@@ -28,6 +28,9 @@ RCPP_MODULE(hashmap_module) {
         .constructor()
         .method("keys",   &hashmap_s::keys)
         .method("values", &hashmap_s::values)
+        .method("clear",  &hashmap_s::clear)
+        .method("remove", &hashmap_s::remove)
+        .method("remove_with_value", &hashmap_s::remove_with_value)
         .method("head",   &hashmap_s::head)
         .method("size",   &hashmap_s::size)
         .method("insert", &hashmap_s::insert)
@@ -36,6 +39,9 @@ RCPP_MODULE(hashmap_module) {
         .constructor()
         .method("keys",   &hashmap_d::keys)
         .method("values", &hashmap_d::values)
+        .method("clear",  &hashmap_d::clear)
+        .method("remove", &hashmap_d::remove)
+        .method("remove_with_value", &hashmap_d::remove_with_value)
         .method("head",   &hashmap_d::head)
         .method("size",   &hashmap_d::size)
         .method("insert", &hashmap_d::insert)
@@ -44,6 +50,9 @@ RCPP_MODULE(hashmap_module) {
         .constructor()
         .method("keys",   &hashmap_i::keys)
         .method("values", &hashmap_i::values)
+        .method("clear",  &hashmap_i::clear)
+        .method("remove", &hashmap_i::remove)
+        .method("remove_with_value", &hashmap_i::remove_with_value)
         .method("head",   &hashmap_i::head)
         .method("size",   &hashmap_i::size)
         .method("insert", &hashmap_i::insert)
