@@ -29,6 +29,9 @@ RCPP_MODULE(multimap_module) {
         .constructor()
         .method("keys",   &multimap_s::keys)
         .method("values", &multimap_s::values)
+        .method("clear",  &multimap_s::clear)
+        .method("remove", &multimap_s::remove)
+        .method("remove_with_value", &multimap_s::remove_with_value)
         .method("head",   &multimap_s::head)
         .method("size",   &multimap_s::size)
         .method("insert", &multimap_s::insert)
@@ -37,6 +40,9 @@ RCPP_MODULE(multimap_module) {
         .constructor()
         .method("keys",   &multimap_d::keys)
         .method("values", &multimap_d::values)
+        .method("clear",  &multimap_d::clear)
+        .method("remove", &multimap_d::remove)
+        .method("remove_with_value", &multimap_d::remove_with_value)
         .method("head",   &multimap_d::head)
         .method("size",   &multimap_d::size)
         .method("insert", &multimap_d::insert)
@@ -45,6 +51,9 @@ RCPP_MODULE(multimap_module) {
         .constructor()
         .method("keys",   &multimap_i::keys)
         .method("values", &multimap_i::values)
+        .method("clear",  &multimap_i::clear)
+        .method("remove", &multimap_i::remove)
+        .method("remove_with_value", &multimap_i::remove_with_value)
         .method("head",   &multimap_i::head)
         .method("size",   &multimap_i::size)
         .method("insert", &multimap_i::insert)
