@@ -132,3 +132,17 @@ test_that("unordered map size works", {
         expect_equal(size(h), 2)
     }
 })
+
+
+test_that("unordered map removes", {
+    for (m in maps) {
+        h <- m("integer")
+        h <- insert(h, 1L, environment())
+        h <- insert(h, 2L, list(a=1))
+        h <- insert(h, 3L, 2)
+        h <- remove(h, 1L)
+        expect_error(h[letters[1]])
+    }
+})
+
+
